<div id="top"></div>

<!-- PROJECT SHIELDS -->
[![MIT License][license-shield]][license-url]
[![Contributors][contributors-shield]][contributors-url]
[![Forks][forks-shield]][forks-url]
[![Stargazers][stars-shield]][stars-url]
[![Issues][issues-shield]][issues-url]

<!-- PROJECT INTRO -->
<br />
<div align="center">
  <h3 align="center">pyqvrelite</h3>

  <p align="center">
    Basic client for interfacing with QVR Pro/Elite API.
    <br />
    <a href="https://github.com/trunet/pyqvrelite"><strong>Explore the docs »</strong></a>
    <br />
    <br />
    <a href="https://github.com/trunet/pyqvrelite">View Demo</a>
    ·
    <a href="https://github.com/trunet/pyqvrelite/issues">Report Bug</a>
    ·
    <a href="https://github.com/trunet/pyqvrelite/issues">Request Feature</a>
  </p>
</div>

<!-- TABLE OF CONTENTS -->
<details>
  <summary>Table of Contents</summary>
  <ol>
    <li>
      <a href="#about-the-project">About The Project</a>
      <ul>
        <li><a href="#built-with">Built With</a></li>
      </ul>
    </li>
    <li>
      <a href="#getting-started">Getting Started</a>
      <ul>
        <li><a href="#prerequisites">Prerequisites</a></li>
        <li><a href="#installation">Installation</a></li>
      </ul>
    </li>
    <li><a href="#usage">Usage</a></li>
    <li><a href="#contributing">Contributing</a></li>
    <li><a href="#license">License</a></li>
    <li><a href="#contact">Contact</a></li>
    <li><a href="#acknowledgments">Acknowledgments</a></li>
  </ol>
</details>

<!-- ABOUT THE PROJECT -->
## About The Project

Initially written by oblogic7, on https://github.com/oblogic7/pyqvrpro. I forked to add QVR Elite support which I'm using as my [PR #4](https://github.com/oblogic7/pyqvrpro/pull/4) is stuck.

<p align="right">(<a href="#top">back to top</a>)</p>

### Built With

* [Python](https://python.org/)

<p align="right">(<a href="#top">back to top</a>)</p>

<!-- GETTING STARTED -->
## Getting Started

To get a local copy up and running follow these simple example steps.

### Prerequisites

* Python >= 3.5

### Installation

```sh
python -m venv .venv
. .venv/bin/activate
pip install pyqvrelite
```

<p align="right">(<a href="#top">back to top</a>)</p>

<!-- USAGE EXAMPLES -->
## Usage

Use this space to show useful examples of how a project can be used. Additional screenshots, code examples and demos work well in this space. You may also link to more resources.

_For more examples, please refer to the [Documentation](https://example.com)_

<p align="right">(<a href="#top">back to top</a>)</p>

<!-- CONTRIBUTING -->
## Contributing

Contributions are what make the open source community such an amazing place to learn, inspire, and create. Any contributions you make are **greatly appreciated**.

If you have a suggestion that would make this better, please fork the repo and create a pull request. You can also simply open an issue with the tag "enhancement".
Don't forget to give the project a star! Thanks again!

1. Fork the Project
2. Create your Feature Branch (`git checkout -b feature/AmazingFeature`)
3. Commit your Changes (`git commit -m 'Add some AmazingFeature'`)
4. Push to the Branch (`git push origin feature/AmazingFeature`)
5. Open a Pull Request

<p align="right">(<a href="#top">back to top</a>)</p>

<!-- LICENSE -->
## License

Distributed under the MIT License. See `LICENSE` for more information.

<p align="right">(<a href="#top">back to top</a>)</p>

<!-- CONTACT -->
## Contact

Wagner Sartori Junior - [@trunet](https://twitter.com/trunet)

Project Link: [https://github.com/trunet/pyqvrelite](https://github.com/trunet/pyqvrelite)

<p align="right">(<a href="#top">back to top</a>)</p>


<!-- ACKNOWLEDGMENTS -->
## Acknowledgments

* [oblogic7/pyqvrpro](https://github.com/oblogic7/pyqvrpro) Thanks for your QVR Pro implementation
* [Img Shields](https://shields.io)

<!-- https://www.markdownguide.org/basic-syntax/#reference-style-links -->
<!-- MARKDOWN LINKS & IMAGES -->
[license-shield]: https://img.shields.io/github/license/trunet/pyqvrelite.svg?style=for-the-badge
[license-url]: https://github.com/trunet/pyqvrelite/blob/master/LICENSE
[contributors-shield]: https://img.shields.io/github/contributors/trunet/pyqvrelite.svg?style=for-the-badge
[contributors-url]: https://github.com/trunet/pyqvrelite/graphs/contributors
[forks-shield]: https://img.shields.io/github/forks/trunet/pyqvrelite.svg?style=for-the-badge
[forks-url]: https://github.com/trunet/pyqvrelite/network/members
[stars-shield]: https://img.shields.io/github/stars/trunet/pyqvrelite.svg?style=for-the-badge
[stars-url]: https://github.com/trunet/pyqvrelite/stargazers
[issues-shield]: https://img.shields.io/github/issues/trunet/pyqvrelite.svg?style=for-the-badge
[issues-url]: https://github.com/trunet/pyqvrelite/issues
